@@ -10,6 +10,7 @@ from flask import render_template
 from flask import url_for
 
 from threading import Thread
+from datetime import datetime
 
 from leselys.themes import themes
 from leselys.helpers import login_required
@@ -26,6 +27,7 @@ signer = leselys.core.signer
 # API
 #######################################################################
 
+
 # Get unreaded counters
 @app.route('/api/counters')
 @login_required
@@ -36,6 +38,7 @@ def get_counters():
         res.append((feed['id'], feed['counter']))
     return jsonify(success=True, content=res)
 
+
 # Add feed
 @app.route('/api/add', methods=['POST'])
 @login_required
@@ -117,6 +120,8 @@ def import_opml():
 def export_opml():
     rsp = make_response(export_to_opml())
     rsp.headers['Content-Type'] = "application/atom+xml"
+    file_date = datetime.today().strftime("%m-%d-%Y")
+    rsp.headers['Content-Disposition'] = "attachment; filename=\"%s_export.opml\"" % file_date
     return rsp
 
 
@@ -159,12 +164,13 @@ def logout():
     rsp.set_cookie('remember', False)
     return rsp
 
+
 # Set theme
 @app.route('/api/settings/theme', methods=['POST'])
 @login_required
 def set_theme():
     theme_name = request.form['theme'].lower()
-    _themes = dict((k.lower(), v) for k,v in themes.iteritems())
+    _themes = dict((k.lower(), v) for k, v in themes.iteritems())
     if not theme_name in _themes.keys():
         return jsonify(success=False, output='Theme not exists')
 
@@ -172,6 +178,7 @@ def set_theme():
     session['theme_name'] = theme_name
     return jsonify(success=True, output='Theme changed')
 
+
 # Set settings
 @app.route('/api/settings', methods=['POST'])
 @login_required
@@ -181,6 +188,7 @@ def change_setting():
     storage.set_setting(setting, value)
     return jsonify(success=True, output="%s setting have been set at %s" % (setting, value))
 
+
 # Set feedsettings
 @app.route('/api/feedsettings', methods=['POST'])
 @login_required
