@@ -16,6 +16,7 @@ from werkzeug.contrib.cache import SimpleCache
 from leselys.backends.storage import _load_storage
 from leselys.backends.session import _load_session
 
+
 class Core(object):
     def __init__(self):
         self.host = "127.0.0.1"
@@ -79,13 +80,12 @@ class Core(object):
         if not self.config.has_section('worker'):
             print('Missing worker section in configuration file')
             sys.exit(1)
-        if not self.config.get('worker', 'broker'):
-            print('Missing broker settion in worker section in configuration file')
-            sys.exit(1)
         if not self.config.has_option('worker', 'interval'):
             self.config.set('worker', 'interval', '10')
         if not self.config.has_option('worker', 'retention'):
             self.config.set('worker', 'retention', '30')
+        if not self.config.has_option('worker', 'story_before_retention'):
+            self.config.set('worker', 'story_before_retention', '50')
 
     def load_storage(self):
         for item in self.config.items('storage'):
@@ -93,7 +93,7 @@ class Core(object):
         del self.storage_settings['type']
 
         self.storage_module = _load_storage(self.config.get('storage', 'type'))
-        self.storage =  self.storage_module(**self.storage_settings)
+        self.storage = self.storage_module(**self.storage_settings)
 
     def load_session(self):
         if self.config.get('session', 'type') == "memory":
