@@ -57,6 +57,10 @@ class Retriever(threading.Thread):
         for entry in self.data:
             title = entry['title']
             link = entry['link']
+
+            if storage.get_story_by_title(title):
+                storage.remove_story(storage.get_story_by_title(title)['_id'])
+
             try:
                 description = entry['content'][0]['value']
             except KeyError:
@@ -100,6 +104,11 @@ class Refresher(threading.Thread):
     def run(self):
         self.data = feedparser.parse(self.feed['url'])
 
+        # Update title if it change (yes some guys change it...)
+        if self.data.feed['title'] != self.feed['title']:
+            self.feed['title'] = self.data.feed['title']
+            storage.update_feed(self.feed['_id'], copy.copy(self.feed))
+
         local_update = get_datetime(self.feed['last_update'])
         remote_update = False
         if self.data.feed.get('updated_parsed'):
@@ -126,14 +135,18 @@ class Refresher(threading.Thread):
             remote_update_raw = get_dicttime(remote_update.timetuple())
 
         if remote_update > local_update:
-            print(':: %s is outdated' % self.feed['title'].encode('utf-8'))
+            print('!! %s is outdated.' % self.feed['title'].encode('utf-8'))
             readed = []
             for entry in storage.get_stories(self.feed['_id']):
                 if entry['read']:
                     readed.append(entry['title'])
-                storage.remove_story(entry['_id'])
 
-            retriever = Retriever(self.data, self.feed, do_retention=False)
+            if len(self.data.entries) <= int(config.get('worker', 'story_before_retention')):
+                do_retention = False
+            else:
+                do_retention = True
+
+            retriever = Retriever(self.data, self.feed, do_retention=do_retention)
             retriever.start()
             retriever.join()
 
@@ -146,6 +159,9 @@ class Refresher(threading.Thread):
             self.feed['last_update'] = remote_update_raw
             storage.update_feed(self.feed_id, self.feed)
 
+        else:
+            print('=> %s is up-to-date.' % self.feed['title'].encode('utf-8'))
+
 #########################################################################
 # Reader object
 #########################################################################
@@ -161,10 +177,15 @@ class Reader(object):
         of http document, we try to find first feed auto discovery url.
         """
         stripped = url.strip()
-        resp = requests.get(stripped)
+
+        try:
+            resp = requests.get(stripped)
+        except Exception as err:
+            return {'success': False, 'output': str(err)}
+
         feed = feedparser.parse(resp.text)
         if feed.version != '':
-            return feed, stripped
+            return {'success': True, 'output': (feed, stripped)}
 
         urls = FeedFinder.parse(resp.text)
         feed_url = ''
@@ -176,10 +197,14 @@ class Reader(object):
             if urlparse(feed_url)[1] == '':
                 # We have empty 'netloc', meaning we have relative url
                 feed_url = urljoin(stripped, feed_url)
-        return feedparser.parse(feed_url), feed_url
+        return {'success': True, 'output': (feedparser.parse(feed_url), feed_url)}
 
     def add(self, url):
-        feed, url = self.get_feed(url)
+        feed_guesser = self.get_feed(url)
+        if feed_guesser['success']:
+            feed, url = feed_guesser['output']
+        else:
+            return feed_guesser
 
         # Bad feed
         if feed.version == '' or not feed.feed.get('title'):
@@ -243,7 +268,6 @@ class Reader(object):
         else:
             stories = storage.get_stories(feed_id)
 
-
         res = []
         entries = []
         if order_type == 'unreaded':
@@ -286,12 +310,21 @@ class Reader(object):
 
                 res.append(story)
 
-            res.sort(key=lambda r: get_datetime(r['last_update']),
-                          reverse=True)
+            res.sort(key=lambda r: get_datetime(r['last_update']), reverse=True)
             entries = res
 
         return {'entries': entries, 'ordering': order_type}
 
+    def get_combined_feed(self):
+        order_type = storage.get_setting('all_items_ordering')
+        if not order_type:
+            storage.set_setting('all_items_ordering', 'unreaded')
+            order_type = storage.get_setting('all_items_ordering')
+        return {'title': 'All stories',
+                'id': 'combined_feed',
+                'counter': self.get_unread(),
+                'ordering': order_type}
+
     def get_feeds(self):
         feeds = []
         for feed in storage.get_feeds():
@@ -318,7 +351,13 @@ class Reader(object):
         feed['counter'] = self.get_unread(feed_id)
         return {'success': True, 'content': feed}
 
-    def get_unread(self, feed_id):
+    def get_unread(self, feed_id=False):
+        if not feed_id:
+            stories = 0
+            for story in storage.all_stories():
+                if not story['read']:
+                    stories += 1
+            return stories
         return len(storage.get_feed_unread(feed_id))
 
     def mark_all_read(self, feed_id):
@@ -362,4 +401,3 @@ class Reader(object):
         story['read'] = False
         storage.update_story(story['_id'], copy.copy(story))
         return {'success': True, 'content': story}
-
