@@ -23,12 +23,12 @@ signer = leselys.core.signer
 
 @app.context_processor
 def get_feeds():
-    return dict(feeds=reader.get_feeds())
+    return dict(feeds=reader.get_feeds(), combined_feed=reader.get_combined_feed())
 
 
 @app.context_processor
 def get_theme():
-    _themes = dict((k.lower(), v) for k,v in themes.iteritems())
+    _themes = dict((k.lower(), v) for k, v in themes.iteritems())
     theme = session.get('theme_name')
     if not theme:
         theme = storage.get_setting('theme_name')
